//  ––––––––––––––––––––––––––––––––––––––––––––––––––––––––
//  Note! I'm still experimenting – code could change
//
//  A not 100% bulletproof attempt to prevent iOS from 
//  page content below modal window while allowing scroll
//  inside the modal itself.
//
//  🏆 Does not require position fixed or overflow  
//     hidden on the body tag  
//
//  ––––––––––––––––––––––––––––––––––––––––––––––––––––––––
(function (IIFE) {
    var check = document.querySelector('input');
    var modal = document.querySelector('.modal');
    //  prevent page scroll   
    var scrollLock = false;
    //  toggle scroll lock state 
    check.addEventListener('change', function (e) { scrollLock = e.target.checked; });
    //  modal window listeners 
    modal.addEventListener('touchstart', onePixelHack, { passive: false });
    modal.addEventListener('scroll', onePixelHack, { passive: false });
    //  One pixel hack 
    //  it seems iOS won't allow scrolling in modal if at top or bottom
    //  – why in that case we shift scrollTop by one pixel (up or down) 
    function onePixelHack(e) {
        if (!scrollLock)
            return;
        var atTop = modal.scrollTop === 0;
        var atBot = modal.scrollHeight - modal.scrollTop === modal.offsetHeight;
        if (atTop || atBot) {
            modal.scrollTop += atTop ? 1 : -1;
            e.preventDefault();
        }
    }
    //  About the passive event option:
    //  As the browser does not know if an event will be cancled it needs to 
    //  run the entire handler script before proceeding. Setting passive
    //  to true tells the browser the handler will not cancel the event and
    //  can proceed without awaiting execution. 
    //    
    //  In this case we want to cancel and as iOS 11.1 by default sets passive 
    //  to true on touchstart and touchmove we need to override it. 
})();